[FFmpeg-cvslog] miscellaneous typo fixes

Diego Biurrun git at videolan.org
Fri Jul 26 11:20:25 CEST 2013


ffmpeg | branch: master | Diego Biurrun <diego at biurrun.de> | Sat May  4 21:18:13 2013 +0200| [03039f4c8cdb4f8e5dc69905f3d73e2a531157e8] | committer: Diego Biurrun

miscellaneous typo fixes

> http://git.videolan.org/gitweb.cgi/ffmpeg.git/?a=commit;h=03039f4c8cdb4f8e5dc69905f3d73e2a531157e8
---

 Changelog                       |    2 +-
 avplay.c                        |    3 ++-
 configure                       |    2 +-
 doc/faq.texi                    |    4 ++--
 libavcodec/aac.h                |    2 +-
 libavcodec/twinvq.c             |    8 ++++----
 libavcodec/wma.c                |    2 +-
 libavcodec/wmaprodec.c          |    4 ++--
 libavcodec/wmavoice.c           |    2 +-
 libavformat/avisynth.c          |   26 +++++++++++++-------------
 libavresample/avresample-test.c |    2 +-
 tests/audiogen.c                |    4 ++--
 12 files changed, 31 insertions(+), 30 deletions(-)

diff --git a/Changelog b/Changelog
index 7a2a7c8..faf0393 100644
--- a/Changelog
+++ b/Changelog
@@ -479,7 +479,7 @@ version 0.5:
 - MXF demuxer
 - VC-1/WMV3/WMV9 video decoder
 - MacIntel support
-- AVISynth support
+- AviSynth support
 - VMware video decoder
 - VP5 video decoder
 - VP6 video decoder
diff --git a/avplay.c b/avplay.c
index ba59a8c..00becbe 100644
--- a/avplay.c
+++ b/avplay.c
@@ -847,7 +847,8 @@ static void video_audio_display(VideoState *s)
                 }
                 av_rdft_calc(s->rdft, data[ch]);
             }
-            // least efficient way to do this, we should of course directly access it but its more than fast enough
+            /* Least efficient way to do this, we should of course
+             * directly access it but it is more than fast enough. */
             for (y = 0; y < s->height; y++) {
                 double w = 1 / sqrt(nb_freq);
                 int a = sqrt(w * sqrt(data[0][2 * y + 0] * data[0][2 * y + 0] + data[0][2 * y + 1] * data[0][2 * y + 1]));
diff --git a/configure b/configure
index 0bd54dd..adda2cf 100755
--- a/configure
+++ b/configure
@@ -173,7 +173,7 @@ Individual component options:
   --disable-filters        disable all filters
 
 External library support:
-  --enable-avisynth        enable reading of AVISynth script files [no]
+  --enable-avisynth        enable reading of AviSynth script files [no]
   --enable-bzlib           enable bzlib [autodetect]
   --enable-frei0r          enable frei0r video filtering
   --enable-gnutls          enable gnutls [no]
diff --git a/doc/faq.texi b/doc/faq.texi
index 088ca03..b400124 100644
--- a/doc/faq.texi
+++ b/doc/faq.texi
@@ -202,8 +202,8 @@ Just create an "input.avs" text file with this single line ...
   avconv -i input.avs
 @end example
 
-For ANY other help on Avisynth, please visit the
- at uref{http://www.avisynth.org/, Avisynth homepage}.
+For ANY other help on AviSynth, please visit the
+ at uref{http://www.avisynth.org/, AviSynth homepage}.
 
 @section How can I join video files?
 
diff --git a/libavcodec/aac.h b/libavcodec/aac.h
index b12d2ba..a7c9995 100644
--- a/libavcodec/aac.h
+++ b/libavcodec/aac.h
@@ -157,7 +157,7 @@ typedef struct LongTermPrediction {
 typedef struct IndividualChannelStream {
     uint8_t max_sfb;            ///< number of scalefactor bands per group
     enum WindowSequence window_sequence[2];
-    uint8_t use_kb_window[2];   ///< If set, use Kaiser-Bessel window, otherwise use a sinus window.
+    uint8_t use_kb_window[2];   ///< If set, use Kaiser-Bessel window, otherwise use a sine window.
     int num_window_groups;
     uint8_t group_len[8];
     LongTermPrediction ltp;
diff --git a/libavcodec/twinvq.c b/libavcodec/twinvq.c
index 887a88c..8c304c6 100644
--- a/libavcodec/twinvq.c
+++ b/libavcodec/twinvq.c
@@ -230,7 +230,7 @@ static void memset_float(float *buf, float val, int size)
  * Evaluate a single LPC amplitude spectrum envelope coefficient from the line
  * spectrum pairs.
  *
- * @param lsp a vector of the cosinus of the LSP values
+ * @param lsp a vector of the cosine of the LSP values
  * @param cos_val cos(PI*i/N) where i is the index of the LPC amplitude
  * @param order the order of the LSP (and the size of the *lsp buffer). Must
  *        be a multiple of four.
@@ -302,9 +302,9 @@ static inline float get_cos(int idx, int part, const float *cos_tab, int size)
  * unexplained condition.
  *
  * @param step the size of a block "siiiibiiii"
- * @param in the cosinus of the LSP data
- * @param part is 0 for 0...PI (positive cossinus values) and 1 for PI...2PI
- *        (negative cossinus values)
+ * @param in the cosine of the LSP data
+ * @param part is 0 for 0...PI (positive cosine values) and 1 for PI...2PI
+ *        (negative cosine values)
  * @param size the size of the whole output
  */
 static inline void eval_lpcenv_or_interp(TwinContext *tctx,
diff --git a/libavcodec/wma.c b/libavcodec/wma.c
index db27646..f5ea64a 100644
--- a/libavcodec/wma.c
+++ b/libavcodec/wma.c
@@ -304,7 +304,7 @@ av_cold int ff_wma_init(AVCodecContext *avctx, int flags2)
     }
 #endif
 
-    /* init MDCT windows : simple sinus window */
+    /* init MDCT windows : simple sine window */
     for (i = 0; i < s->nb_block_sizes; i++) {
         ff_init_ff_sine_windows(s->frame_len_bits - i);
         s->windows[i] = ff_sine_windows[s->frame_len_bits - i];
diff --git a/libavcodec/wmavoice.c b/libavcodec/wmavoice.c
index 219f4e5..0ba2c48 100644
--- a/libavcodec/wmavoice.c
+++ b/libavcodec/wmavoice.c
@@ -620,7 +620,7 @@ static void calc_input_response(WMAVoiceContext *s, float *lpcs,
     }
 
     /* calculate the Hilbert transform of the gains, which we do (since this
-     * is a sinus input) by doing a phase shift (in theory, H(sin())=cos()).
+     * is a sine input) by doing a phase shift (in theory, H(sin())=cos()).
      * Hilbert_Transform(RDFT(x)) = Laplace_Transform(x), which calculates the
      * "moment" of the LPCs in this filter. */
     s->dct.dct_calc(&s->dct, lpcs);
diff --git a/libavformat/avisynth.c b/libavformat/avisynth.c
index 43b3da5..b846c9f 100644
--- a/libavformat/avisynth.c
+++ b/libavformat/avisynth.c
@@ -1,5 +1,5 @@
 /*
- * AVISynth support
+ * AviSynth support
  * Copyright (c) 2006 DivX, Inc.
  *
  * This file is part of Libav.
@@ -32,29 +32,29 @@ typedef struct {
   DWORD read;
   LONG chunck_size;
   LONG chunck_samples;
-} AVISynthStream;
+} AviSynthStream;
 
 typedef struct {
   PAVIFILE file;
   AVISynthStream *streams;
   int nb_streams;
   int next_stream;
-} AVISynthContext;
+} AviSynthContext;
 
 static int avisynth_read_header(AVFormatContext *s)
 {
-  AVISynthContext *avs = s->priv_data;
+  AviSynthContext *avs = s->priv_data;
   HRESULT res;
   AVIFILEINFO info;
   DWORD id;
   AVStream *st;
-  AVISynthStream *stream;
+  AviSynthStream *stream;
   wchar_t filename_wchar[1024] = { 0 };
   char filename_char[1024] = { 0 };
 
   AVIFileInit();
 
-  /* avisynth can't accept UTF-8 filename */
+  /* AviSynth cannot accept UTF-8 file names. */
   MultiByteToWideChar(CP_UTF8, 0, s->filename, -1, filename_wchar, 1024);
   WideCharToMultiByte(CP_THREAD_ACP, 0, filename_wchar, -1, filename_char, 1024, NULL, NULL);
   res = AVIFileOpen(&avs->file, filename_char, OF_READ|OF_SHARE_DENY_WRITE, NULL);
@@ -73,7 +73,7 @@ static int avisynth_read_header(AVFormatContext *s)
       return -1;
     }
 
-  avs->streams = av_mallocz(info.dwStreams * sizeof(AVISynthStream));
+  avs->streams = av_mallocz(info.dwStreams * sizeof(AviSynthStream));
 
   for (id=0; id<info.dwStreams; id++)
     {
@@ -154,9 +154,9 @@ static int avisynth_read_header(AVFormatContext *s)
 
 static int avisynth_read_packet(AVFormatContext *s, AVPacket *pkt)
 {
-  AVISynthContext *avs = s->priv_data;
+  AviSynthContext *avs = s->priv_data;
   HRESULT res;
-  AVISynthStream *stream;
+  AviSynthStream *stream;
   int stream_id = avs->next_stream;
   LONG read_size;
 
@@ -188,7 +188,7 @@ static int avisynth_read_packet(AVFormatContext *s, AVPacket *pkt)
 
 static int avisynth_read_close(AVFormatContext *s)
 {
-  AVISynthContext *avs = s->priv_data;
+  AviSynthContext *avs = s->priv_data;
   int i;
 
   for (i=0;i<avs->nb_streams;i++)
@@ -204,7 +204,7 @@ static int avisynth_read_close(AVFormatContext *s)
 
 static int avisynth_read_seek(AVFormatContext *s, int stream_index, int64_t pts, int flags)
 {
-  AVISynthContext *avs = s->priv_data;
+  AviSynthContext *avs = s->priv_data;
   int stream_id;
 
   for (stream_id = 0; stream_id < avs->nb_streams; stream_id++)
@@ -217,8 +217,8 @@ static int avisynth_read_seek(AVFormatContext *s, int stream_index, int64_t pts,
 
 AVInputFormat ff_avisynth_demuxer = {
     .name           = "avisynth",
-    .long_name      = NULL_IF_CONFIG_SMALL("AVISynth"),
-    .priv_data_size = sizeof(AVISynthContext),
+    .long_name      = NULL_IF_CONFIG_SMALL("AviSynth"),
+    .priv_data_size = sizeof(AviSynthContext),
     .read_header    = avisynth_read_header,
     .read_packet    = avisynth_read_packet,
     .read_close     = avisynth_read_close,
diff --git a/libavresample/avresample-test.c b/libavresample/avresample-test.c
index 81e9bf0..697b4ba 100644
--- a/libavresample/avresample-test.c
+++ b/libavresample/avresample-test.c
@@ -91,7 +91,7 @@ static void audiogen(AVLFG *rnd, void **data, enum AVSampleFormat sample_fmt,
 
     k = 0;
 
-    /* 1 second of single freq sinus at 1000 Hz */
+    /* 1 second of single freq sine at 1000 Hz */
     a = 0;
     for (i = 0; i < 1 * sample_rate && k < nb_samples; i++, k++) {
         v = sin(a) * 0.30;
diff --git a/tests/audiogen.c b/tests/audiogen.c
index 4fa4656..ce6f785 100644
--- a/tests/audiogen.c
+++ b/tests/audiogen.c
@@ -48,7 +48,7 @@ static unsigned int myrnd(unsigned int *seed_ptr, int n)
 
 #define COS_TABLE_BITS 7
 
-/* integer cosinus */
+/* integer cosine */
 static const unsigned short cos_table[(1 << COS_TABLE_BITS) + 2] = {
     0x8000, 0x7ffe, 0x7ff6, 0x7fea, 0x7fd9, 0x7fc2, 0x7fa7, 0x7f87,
     0x7f62, 0x7f38, 0x7f0a, 0x7ed6, 0x7e9d, 0x7e60, 0x7e1e, 0x7dd6,
@@ -180,7 +180,7 @@ int main(int argc, char **argv)
     if ((ext = strrchr(argv[1], '.')) != NULL && !strcmp(ext, ".wav"))
         put_wav_header(sample_rate, nb_channels, 6 * sample_rate);
 
-    /* 1 second of single freq sinus at 1000 Hz */
+    /* 1 second of single freq sine at 1000 Hz */
     a = 0;
     for (i = 0; i < 1 * sample_rate; i++) {
         v = (int_cos(a) * 10000) >> FRAC_BITS;



More information about the ffmpeg-cvslog mailing list
diff --git a/libavcodec/wmaprodec.c b/libavcodec/wmaprodec.c
index d3bd381..bbf3216 100644
--- a/libavcodec/wmaprodec.c
+++ b/libavcodec/wmaprodec.c
@@ -125,7 +125,7 @@ static VLC              vec4_vlc;         ///< 4 coefficients per symbol
 static VLC              vec2_vlc;         ///< 2 coefficients per symbol
 static VLC              vec1_vlc;         ///< 1 coefficient per symbol
 static VLC              coef_vlc[2];      ///< coefficient run length vlc codes
-static float            sin64[33];        ///< sinus table for decorrelation
+static float            sin64[33];        ///< sine table for decorrelation
 
 /**
  * @brief frame specific decoder context for a single channel
@@ -449,7 +449,7 @@ static av_cold int decode_init(AVCodecContext *avctx)
                      1.0 / (1 << (WMAPRO_BLOCK_MIN_BITS + i - 1))
                      / (1 << (s->bits_per_sample - 1)));
 
     /** init MDCT windows: simple sinus window */
     for (i = 0; i < WMAPRO_BLOCK_SIZES; i++) {
         const int win_idx = WMAPRO_BLOCK_MAX_BITS - i;
         ff_init_ff_sine_windows(win_idx);
@@ -449,7 +449,7 @@ static av_cold int decode_init(AVCodecContext *avctx)
                      / (1 << (s->bits_per_sample - 1)));
 
-    /** init MDCT windows: simple sinus window */
+    /** init MDCT windows: simple sine window */
     for (i = 0; i < WMAPRO_BLOCK_SIZES; i++) {
         const int win_idx = WMAPRO_BLOCK_MAX_BITS - i;